==> cloud-4.3.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/JoinSelectBlock.tsx <==
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import EntityData from 'model/EntityData';
import LabelBlock from 'molecules/LabelBlock';
import SelectBlock from 'molecules/SelectBlock';
import { useEffect, useState } from 'react';

const convertLabel = (entityData: EntityData, labelFormat: string): string => {
  let output = labelFormat;
  for (const key in entityData.attributes) {
    output = output.replaceAll(`{${key}}`, entityData.attributes[key]);
  }
  return output;
}

/**
 * Block of select view.
 *
 * @param
 */
const JoinSelectBlock = ({ label, value, setValue, entityTypeId, keyColumn, optionLabel, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  entityTypeId: string,
  keyColumn: string,
  optionLabel: string,
  required: boolean,
  readOnly: boolean,
}) => {

  const { getEntityListAll } = useDrupalJsonApi();
  const [dataList, setDataList] = useState<EntityData[]>([]);

  useEffect(() => {
    getEntityListAll(entityTypeId).then((entityDataList) => {
      setDataList(entityDataList);
    })
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (readOnly) {
    // If the corresponding data exists in dataList,
    // use a notation such as "label name (key name)".
    // Otherwise, only the key name is used, e.g., "key name".
    let labelName = value;
    const filtered = dataList.filter((d) => d.attributes[keyColumn] === value);
    if (filtered.length >= 1 && ('name' in filtered[0].attributes)) {
      labelName = filtered[0].attributes['name'];
    }

    return <LabelBlock
      name={label}
      value={labelName !== value ? `${labelName} (${value})` : value} />;
  }

  return <SelectBlock
    label={label}
    value={value}
    setValue={setValue}
    recordList={dataList.map((d) => {
      return { value: d.attributes[keyColumn], label: convertLabel(d, optionLabel) };
    })}
    required={required} />;

}

export default JoinSelectBlock;

==> cloud-5.0.0-rc1.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/JoinSelectBlock.tsx <==
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import EntityData from 'model/EntityData';
import LabelBlock from 'molecules/LabelBlock';
import SelectBlock from 'molecules/SelectBlock';
import { useEffect, useState } from 'react';

const convertLabel = (entityData: EntityData, labelFormat: string): string => {
  let output = labelFormat;
  for (const key in entityData.attributes) {
    output = output.replaceAll(`{${key}}`, entityData.attributes[key]);
  }
  return output;
}

/**
 * Block of select view.
 *
 * @param
 */
const JoinSelectBlock = ({ label, value, defaultValue, setValue, entityTypeId, keyColumn, optionLabel, required, readOnly }: {
  label: string,
  value: string,
  defaultValue: string,
  setValue: (s: string) => void,
  entityTypeId: string,
  keyColumn: string,
  optionLabel: string,
  required: boolean,
  readOnly: boolean,
}) => {

  const { getEntityListAll } = useDrupalJsonApi();
  const [dataList, setDataList] = useState<EntityData[]>([]);

  useEffect(() => {
    getEntityListAll(entityTypeId).then((entityDataList) => {
      setDataList(entityDataList);
    })
  // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (readOnly) {
    // If the corresponding data exists in dataList,
    // use a notation such as "label name (key name)".
    // Otherwise, only the key name is used, e.g., "key name".
    let labelName = value;
    const filtered = dataList.filter((d) => d.attributes[keyColumn] === value);
    if (filtered.length >= 1 && ('name' in filtered[0].attributes)) {
      labelName = filtered[0].attributes['name'];
    }

    return <LabelBlock
      name={label}
      value={labelName !== value ? `${labelName} (${value})` : value} />;
  }

  return <SelectBlock
    label={label}
    value={value}
    setValue={setValue}
    defaultValue={defaultValue}
    recordList={dataList.map((d) => {
      return { value: d.attributes[keyColumn], label: convertLabel(d, optionLabel) };
    })}
    required={required} />;

}

export default JoinSelectBlock;
